'use strict';

var errors = require('@backstage/errors');
var pluginCatalogNode = require('@backstage/plugin-catalog-node');
var limiterFactory = require('p-limit');

function _interopDefaultCompat (e) { return e && typeof e === 'object' && 'default' in e ? e : { default: e }; }

var limiterFactory__default = /*#__PURE__*/_interopDefaultCompat(limiterFactory);

class AwsS3DiscoveryProcessor {
  constructor(reader) {
    this.reader = reader;
  }
  getProcessorName() {
    return "AwsS3DiscoveryProcessor";
  }
  async readLocation(location, optional, emit, parser) {
    if (location.type !== "s3-discovery") {
      return false;
    }
    try {
      const output = await this.doRead(location.target);
      for (const item of output) {
        for await (const parseResult of parser({
          data: item.data,
          location: { type: location.type, target: item.url }
        })) {
          emit(parseResult);
        }
      }
    } catch (error) {
      const message = `Unable to read ${location.type}, ${error}`;
      if (errors.isError(error) && error.name === "NotFoundError") {
        if (!optional) {
          emit(pluginCatalogNode.processingResult.notFoundError(location, message));
        }
      } else {
        emit(pluginCatalogNode.processingResult.generalError(location, message));
      }
    }
    return true;
  }
  async doRead(location) {
    const limiter = limiterFactory__default.default(5);
    const response = await this.reader.readTree(location);
    const responseFiles = await response.files();
    const output = responseFiles.map(async (file) => ({
      url: file.path,
      data: await limiter(file.content)
    }));
    return Promise.all(output);
  }
}

exports.AwsS3DiscoveryProcessor = AwsS3DiscoveryProcessor;
//# sourceMappingURL=AwsS3DiscoveryProcessor.cjs.js.map
